mystic.math module documentation
================================

approx module
-------------

.. automodule:: mystic.math.approx
..  :exclude-members: +

compressed module
-----------------

.. automodule:: mystic.math.compressed
..  :exclude-members: +

discrete module
---------------

.. automodule:: mystic.math.discrete
    :exclude-members: +point_mass, measure, product_measure, scenario
.. autoclass:: point_mass
..  :exclude-members: +
.. autoclass:: measure
    :exclude-members: +coords, get_expect, mean
.. autoclass:: product_measure
    :exclude-members: +coords, get_expect
.. autoclass:: scenario
    :exclude-members: +coords, get_mean_value

distance module
---------------

.. automodule:: mystic.math.distance
..  :exclude-members: +

grid module
-----------

.. automodule:: mystic.math.grid
..  :exclude-members: +

integrate module
----------------

.. automodule:: mystic.math.integrate
..  :exclude-members: +

interpolate module
------------------

.. automodule:: mystic.math.interpolate
..  :exclude-members: +

legacydata module
-----------------

.. automodule:: mystic.math.legacydata
..  :exclude-members: +

measures module
---------------

.. automodule:: mystic.math.measures
..  :exclude-members: +_flat_split

poly module
-----------

.. automodule:: mystic.math.poly
..  :exclude-members: +

samples module
--------------

.. automodule:: mystic.math.samples
..  :exclude-members: +

stats module
------------

.. automodule:: mystic.math.stats
..  :exclude-members: +
